import React, { Component } from 'react';
import {
  TouchableOpacity,
  Dimensions,
  StyleSheet,
  Animated,
  View,
} from 'react-native';
import PropTypes from 'prop-types';

const { width } = Dimensions.get('window');

class Header extends Component {
  static propTypes = {
    title: PropTypes.string.isRequired,
    animatedValue: PropTypes.object.isRequired,
    isCardFull: PropTypes.bool,
    onLocationPress: PropTypes.func,
    onClosePress: PropTypes.func,
  };

  static defaultProps = {
    isCardFull: false,
    onLocationPress: () => { },
    onClosePress: () => { }
  };

  render() {
    const {
      animatedValue,
      isCardFull,
      onClosePress,
      headerCloseIconUrl,
    } = this.props;

    return (
      <View style={styles.sceneHeader}>
        {
          isCardFull
            ? <TouchableOpacity onPress={
                () => {
                  if (isCardFull) { onClosePress(); }
                }}
              >
                <Animated.Image
                  source={{ uri: headerCloseIconUrl }}
                  style={[styles.headerIcon, {
                    transform: [{
                      rotate: animatedValue.interpolate({
                        inputRange: [-200, -100, 0],
                        outputRange: ['360deg', '0deg', '0deg'],
                        extrapolate: 'clamp',
                      }),
                    }],
                  }]}
                />
            </TouchableOpacity>
            : null
        }

      </View>
    );
  }
}

const styles = StyleSheet.create({
  sceneHeader: {
    position: 'absolute',
    top: 0,
    width,
    height: 30,
    backgroundColor: 'transparent',
    flexDirection: 'row',
    justifyContent: 'flex-end',
    alignItems: 'center',
    paddingHorizontal: 15,
    paddingTop: 10,
  },
  fontHeader: {
    color: 'white',
    textAlign: 'center',
    fontWeight: '600',
    flex: 6,
  },
  headerIcon: {
    width: 20,
    height: 20,
    resizeMode: 'contain',
    tintColor: '#000',
    margin: 10,
  },
});

export default Header;
